@@ -25,6 +25,7 @@ else:
 
 __all__ = (
     "AvailSuppressionTypeDef",
+    "BumperTypeDef",
     "CdnConfigurationTypeDef",
     "DashConfigurationTypeDef",
     "HlsConfigurationTypeDef",
@@ -44,6 +45,8 @@ AvailSuppressionTypeDef = TypedDict(
     total=False,
 )
 
+BumperTypeDef = TypedDict("BumperTypeDef", {"EndUrl": str, "StartUrl": str}, total=False)
+
 CdnConfigurationTypeDef = TypedDict(
     "CdnConfigurationTypeDef",
     {"AdSegmentUrlPrefix": str, "ContentSegmentUrlPrefix": str},
@@ -75,6 +78,7 @@ PlaybackConfigurationTypeDef = TypedDict(
     {
         "AdDecisionServerUrl": str,
         "AvailSuppression": "AvailSuppressionTypeDef",
+        "Bumper": "BumperTypeDef",
         "CdnConfiguration": "CdnConfigurationTypeDef",
         "DashConfiguration": "DashConfigurationTypeDef",
         "HlsConfiguration": "HlsConfigurationTypeDef",
@@ -102,6 +106,7 @@ GetPlaybackConfigurationResponseTypeDef = TypedDict(
     {
         "AdDecisionServerUrl": str,
         "AvailSuppression": "AvailSuppressionTypeDef",
+        "Bumper": "BumperTypeDef",
         "CdnConfiguration": "CdnConfigurationTypeDef",
         "DashConfiguration": "DashConfigurationTypeDef",
         "HlsConfiguration": "HlsConfigurationTypeDef",
@@ -138,6 +143,7 @@ PutPlaybackConfigurationResponseTypeDef = TypedDict(
     {
         "AdDecisionServerUrl": str,
         "AvailSuppression": "AvailSuppressionTypeDef",
+        "Bumper": "BumperTypeDef",
         "CdnConfiguration": "CdnConfigurationTypeDef",
         "DashConfiguration": "DashConfigurationTypeDef",
         "HlsConfiguration": "HlsConfigurationTypeDef",
